This function reads a `samples.csv` file from the given path and merges reads using PEAR. If only `R1` is available, the sample is skipped. Output is saved to `results/merged/` inside the same folder.
This function reads a `samples.csv` file from the given path and merges reads using PEAR. If only `R1` is available, the sample is skipped. Output is saved to `results/merged/` inside the same folder.